/*
 * avards.h: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#define MAXDELAY 100

// modes correspond with aAspectInfo[]
#define MODE_AUTO  0
#define MODE_43    1
#define MODE_L149  2
#define MODE_L169  3
#define MODE_LG169 4
#define MODE_169   5

struct cParameter
{
  int ShowInMainMenu;
  int AutoStart;
  int Mode;
  char *pszDevVideo;
  char *pszDvb;
  char *pszDevVbi;
  int PanToneTolerance;
  int PanToneBlackMax;
  int Overscan_pct;
  int MaxLogoWidth_pct;
  int PollRate;
  int Delay;
  int FrontendHasLockTest;
  int Overzoom;
};

extern cParameter config;
